@@ -50,15 +50,6 @@
 
 #include "error.h"
 
-/* conversions */
-#define USEC_PER_SEC 	1000000
-#define NSEC_PER_SEC 	1000000000
-#define USEC_TO_NSEC(u) ((u) * 1000)
-#define USEC_TO_SEC(u) 	((u) / USEC_PER_SEC)
-#define NSEC_TO_USEC(n) ((n) / 1000)
-#define SEC_TO_NSEC(s) 	((s) * NSEC_PER_SEC)
-#define SEC_TO_USEC(s) 	((s) * USEC_PER_SEC)
-
 /* test timeout */
 #define TIMEOUT 2
 
@@ -519,14 +510,6 @@ int pending_interrupt(void)
 	return interrupted = sigismember(&pending, SIGINT);
 }
 
-static inline void tsnorm(struct timespec *ts)
-{
-	while (ts->tv_nsec >= NSEC_PER_SEC) {
-		ts->tv_nsec -= NSEC_PER_SEC;
-		ts->tv_sec++;
-	}
-}
-
 /*
  * this routine serves two purposes:
  *   1. report progress
@@ -1327,6 +1310,12 @@ void process_command_line(int argc, char **argv)
 			break;
 		case 'g':
 			ngroups = strtol(optarg, NULL, 10);
+			if (ngroups > num_processors) {
+					pi_error("the number of groups cannot exceed "
+					 "the number of online processors (%ld)\n",
+					 num_processors);
+				exit(-1);
+			}
 			pi_info("number of groups set to %d\n", ngroups);
 			break;
 		case 'r':
